import{v as s}from"./icons.e9d866c3.js";import{d as r,a as c,b as d,c as i,e as _,z as l,U as b,q as u}from"./registerWidgets.787b786f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="28190e0a-a028-40b5-bd2b-6d72850b5759",e._sentryDebugIdIdentifier="sentry-dbid-28190e0a-a028-40b5-bd2b-6d72850b5759")}catch{}})();const p=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=c("icon");return d(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=f=>t("exitFullscreenPreview"))},[_(a,{class:"icon",path:l(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),b(" Editor ")])}}});const v=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.86ee95d9.js.map
