import"./registerWidgets.787b786f.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="f8ec2713-391a-4b97-8840-239eae1ca601",x._sentryDebugIdIdentifier="sentry-dbid-f8ec2713-391a-4b97-8840-239eae1ca601")}catch{}})();const r=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{r as u};
//# sourceMappingURL=uuid.164febd5.js.map
