import{d as b,K as f,b as y,t as g,z as s,J as _}from"./registerWidgets.787b786f.js";import{a as w}from"./asyncComputed.3103aa62.js";import"./gateway.db5ee0aa.js";import{M as i}from"./member.ba6260a0.js";import"./index.7b79e8ba.js";import{C as I}from"./CrudView.e0b3c1f9.js";import"./passwordlessManager.42099b8c.js";import"./pubsub.dd86dbcf.js";import"./activeRecord.f8b90405.js";import"./DropdownMenu.d6704c7d.js";import"./Modal.9eb19c24.js";import"./LoadingIndicator.f28b4a2c.js";import"./lottie.221bef6b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="6d4f266b-50a0-408a-8088-d31702b800d8",e._sentryDebugIdIdentifier="sentry-dbid-6d4f266b-50a0-408a-8088-d31702b800d8")}catch{}})();const K=b({__name:"Members",setup(e){const o=_().params.organizationId,m=[{key:"email",label:"Email"}],l=async t=>{await i.create(o,t.email),p()},{loading:d,result:c,refetch:p}=w(()=>i.list(o)),u=f(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=c.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:s(d),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:s(u),"create-button-text":"Add members",fields:m,onCreate:l},null,8,["loading","table"]))}});export{K as default};
//# sourceMappingURL=Members.ed2fbbd8.js.map
