[data-v-c9b2b4e6]:root{--main-font-family: DM Sans, sans-serif}[data-v-c9b2b4e6]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-c9b2b4e6]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-c9b2b4e6]{background-color:#fff;padding:10px}.login[data-v-c9b2b4e6]{display:grid;height:100%;grid-template-rows:auto 1fr;justify-items:center}.login .passwordless[data-v-c9b2b4e6]{width:640px;max-width:calc(100vw - 40px);align-self:center}.login .passwordless[data-v-c9b2b4e6] .auth-info,.login .passwordless[data-v-c9b2b4e6] .auth-token{display:flex;flex-direction:column;align-items:stretch;background-color:#fff;padding:100px 20px;box-shadow:0 0 40px #0000001a;border-radius:4px}.login .passwordless[data-v-c9b2b4e6] .auth-info .next-button,.login .passwordless[data-v-c9b2b4e6] .auth-info .secondary-button,.login .passwordless[data-v-c9b2b4e6] .auth-token .next-button,.login .passwordless[data-v-c9b2b4e6] .auth-token .secondary-button{cursor:pointer;display:flex;flex-direction:row;justify-content:center;align-items:center;padding:8px 20px;gap:10px;border:none;border-radius:4px;font-family:DM Sans,sans-serif;text-decoration:none;background:#d14056;color:#fff;box-shadow:0 2px 4px #00000026;font-size:16px;height:30px}.login .passwordless[data-v-c9b2b4e6] .auth-info .next-button:hover,.login .passwordless[data-v-c9b2b4e6] .auth-info .secondary-button:hover,.login .passwordless[data-v-c9b2b4e6] .auth-token .next-button:hover,.login .passwordless[data-v-c9b2b4e6] .auth-token .secondary-button:hover{background:#e55b70;box-shadow:0 4px 12px #00000026}.login .passwordless[data-v-c9b2b4e6] .auth-info .next-button:active,.login .passwordless[data-v-c9b2b4e6] .auth-info .next-button active,.login .passwordless[data-v-c9b2b4e6] .auth-info .secondary-button:active,.login .passwordless[data-v-c9b2b4e6] .auth-info .secondary-button active,.login .passwordless[data-v-c9b2b4e6] .auth-token .next-button:active,.login .passwordless[data-v-c9b2b4e6] .auth-token .next-button active,.login .passwordless[data-v-c9b2b4e6] .auth-token .secondary-button:active,.login .passwordless[data-v-c9b2b4e6] .auth-token .secondary-button active{background:#e55b70;box-shadow:inset 0 4px 4px #0000000f}
