import{d as o,b as c,c as a,q as d}from"./registerWidgets.787b786f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="7b6c4f24-5ffa-470a-b8bd-027b8dcc3c7e",e._sentryDebugIdIdentifier="sentry-dbid-7b6c4f24-5ffa-470a-b8bd-027b8dcc3c7e")}catch{}})();const _=["href"],r=o({__name:"DocsButton",props:{path:null},setup(e){return(t,n)=>{var s;return c(),a("a",{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank"}," Docs ",8,_)}}});const b=d(r,[["__scopeId","data-v-9fec5678"]]);export{b as D};
//# sourceMappingURL=DocsButton.847a689f.js.map
