import{S as m}from"./Sidebar.05ee0a40.js";import{N as p}from"./Navbar.851ecb91.js";import{E as d,F as l,G as u}from"./icons.e9d866c3.js";import{d as b,K as _,b as f,c as g,e as t,z as r,x as v,F as y,J as z,a as w,q as I}from"./registerWidgets.787b786f.js";import{a as h}from"./asyncComputed.3103aa62.js";import"./gateway.db5ee0aa.js";import{O}from"./organization.a8c57ce6.js";import"./index.7b79e8ba.js";import"./Tooltip.1dd3f65a.js";import"./logo.084e5d7c.js";import"./passwordlessManager.42099b8c.js";import"./pubsub.dd86dbcf.js";import"./activeRecord.f8b90405.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="9e7bae4e-5409-46c5-a315-b8cac99f6456",e._sentryDebugIdIdentifier="sentry-dbid-9e7bae4e-5409-46c5-a315-b8cac99f6456")}catch{}})();const x={class:"organization"},k=b({__name:"Organization",setup(e){const n=z().params.organizationId,{result:o}=h(()=>O.get(n)),s=_(()=>o.value?[{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(B,D)=>{const c=w("router-view");return f(),g(y,null,[t(p,{breadcrumb:r(s)},null,8,["breadcrumb"]),v("div",x,[t(m,{class:"sidebar",sections:r(i)},null,8,["sections"]),t(c)])],64)}}});const R=I(k,[["__scopeId","data-v-7eef90b7"]]);export{R as default};
//# sourceMappingURL=Organization.0f2cfd48.js.map
