import{q as o,a as r,b as i,t as d,f as c,g as p,_,h as u,k as l,T as f,P as h,C as g,M as y,s as m,i as b,j as s,l as v,m as w,n as k}from"./registerWidgets.787b786f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3e08cc6d-d1db-4823-a400-d8aa20a05dac",e._sentryDebugIdIdentifier="sentry-dbid-3e08cc6d-d1db-4823-a400-d8aa20a05dac")}catch{}})();const I={};function x(e,t){const n=r("router-view");return i(),d(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=o(I,[["render",x]]),a=c({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.932b8c0e.js"),["assets/Player.932b8c0e.js","assets/index.a4839d52.js","assets/registerWidgets.787b786f.js","assets/registerWidgets.448db7e9.css","assets/uuid.164febd5.js","assets/broker.d0c95620.js","assets/passwordlessManager.42099b8c.js","assets/pubsub.dd86dbcf.js","assets/icons.e9d866c3.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.9fa1407c.js","assets/Passwordless.a8ede9c5.js","assets/CircularLoading.738c357f.js","assets/lottie.221bef6b.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.86ac0c56.css","assets/executeJs.0a44fba5.js","assets/PlayerNavbar.7e0c6963.js","assets/PlayerNavbar.adff8b48.css","assets/WidgetsFrame.ffa4e614.js","assets/colors.d63f40df.js","assets/WidgetsFrame.701a818b.css","assets/Modal.9eb19c24.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/broker.5f3abad8.css","assets/DashPlayer.b825c6ff.js","assets/runnerData.7ed5e5ab.js","assets/DashPlayer.ef4a798d.css","assets/asyncComputed.3103aa62.js","assets/Player.df829dc6.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{const e=u({render:()=>l(A)});f.init(),e.use(a),e.use(h),e.mount("#app"),e.component("VSelect",g),e.component("Markdown",y),e.component("Message",m),b(e,a),s(e,v),s(e,w),s(e,k)};D();
//# sourceMappingURL=player.3d4e5fb1.js.map
