import{q as t,b as s,c as d}from"./registerWidgets.787b786f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="314df2b5-5b9e-45de-8518-a80d83fb045d",e._sentryDebugIdIdentifier="sentry-dbid-314df2b5-5b9e-45de-8518-a80d83fb045d")}catch{}})();const o={},r={class:"organization-settings"};function i(e,n){return s(),d("div",r,"Organization settings")}const c=t(o,[["render",i]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.49af724d.js.map
