import{P as n}from"./Passwordless.a8ede9c5.js";import{N as r}from"./Navbar.851ecb91.js";import{d,b as i,c,e as t,H as p,q as _}from"./registerWidgets.787b786f.js";import{M as m}from"./member.ba6260a0.js";import"./CircularLoading.738c357f.js";import"./lottie.221bef6b.js";import"./icons.e9d866c3.js";import"./passwordlessManager.42099b8c.js";import"./pubsub.dd86dbcf.js";import"./logo.084e5d7c.js";import"./asyncComputed.3103aa62.js";import"./gateway.db5ee0aa.js";import"./activeRecord.f8b90405.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="a1ddad75-91ba-4725-94a5-13dd5a256ff9",e._sentryDebugIdIdentifier="sentry-dbid-a1ddad75-91ba-4725-94a5-13dd5a256ff9")}catch{}})();const f={class:"login"},l=d({__name:"Login",setup(e){const o=p();async function s(a){await m.login(),o.push({name:"home"})}return(a,u)=>(i(),c("div",f,[t(r,{class:"nav"}),t(n,{class:"passwordless",onDone:s})]))}});const B=_(l,[["__scopeId","data-v-c9b2b4e6"]]);export{B as default};
//# sourceMappingURL=Login.76684c89.js.map
